@@ -1,6 +1,6 @@
 undef $VERSION;
 package Bio::Roary::CommandLine::RoaryPostAnalysis;
-$Bio::Roary::CommandLine::RoaryPostAnalysis::VERSION = '3.3.2';
+$Bio::Roary::CommandLine::RoaryPostAnalysis::VERSION = '3.3.3';
 # ABSTRACT: Perform the post analysis on the pan genome
 
 
@@ -103,9 +103,10 @@ sub run {
         die $self->usage_text;
     }
 
+    my $input_files = $self->_read_file_into_array($self->input_files);
     my $obj = Bio::Roary::PostAnalysis->new(
       fasta_files                     =>  $self->_read_file_into_array($self->fasta_files) ,
-      input_files                     =>  $self->_read_file_into_array($self->input_files) ,
+      input_files                     =>  $input_files ,
       output_filename                 =>  $self->output_filename            ,
       output_pan_geneome_filename     =>  $self->output_pan_geneome_filename,
       output_statistics_filename      =>  $self->output_statistics_filename ,
@@ -129,30 +130,37 @@ sub run {
         remove_tree('split_groups');
     }
 
-
     if($self->output_multifasta_files == 1)
     {
-		print "Aligning each cluster\n" if($self->verbose);
+	  print "Aligning each cluster\n" if($self->verbose);
       my $output_gene_files = $self->_find_input_files;
       my $seg = Bio::Roary::External::GeneAlignmentFromNucleotides->new(
         fasta_files         => $output_gene_files,
-        job_runner          => $self->job_runner,
+        job_runner          => $self->_is_lsf_job_runner_available ? 'LSF' : $self->job_runner,
         translation_table   => $self->translation_table,
         core_definition     => $self->core_definition,
         cpus                => $self->cpus,
 		verbose             => $self->verbose,
 		mafft               => $self->mafft,
+        dont_delete_files   => $self->dont_delete_files,
+        num_input_files     => $#{$input_files},
       );
       $seg->run();
-	  
-      # Cleanup intermediate multifasta files
-      if($self->dont_delete_files == 0)
-      {
-        remove_tree('pan_genome_sequences');
-      }
     }
-     
+}
 
+sub _is_lsf_job_runner_available
+{
+    my ($self) = @_;
+    my $rc = eval "require Bio::Roary::JobRunner::LSF; 1;";
+    if(defined($rc) && $rc == 1)
+    {
+        return 1;
+    }
+    else
+    {
+        return 0;
+    }
 }
 
 sub _find_input_files
@@ -224,7 +232,7 @@ Bio::Roary::CommandLine::RoaryPostAnalysis - Perform the post analysis on the pa
 
 =head1 VERSION
 
-version 3.3.2
+version 3.3.3
 
 =head1 SYNOPSIS
 
