@@ -1,32 +1,52 @@
 package Bio::Roary::External::GeneAlignmentFromNucleotides;
-$Bio::Roary::External::GeneAlignmentFromNucleotides::VERSION = '3.3.2';
+$Bio::Roary::External::GeneAlignmentFromNucleotides::VERSION = '3.3.3';
 # ABSTRACT: Take in multi-FASTA files of nucleotides and align each file with PRANK or MAFFT
 
 
 use Moose;
 with 'Bio::Roary::JobRunner::Role';
 
-has 'fasta_files'       => ( is => 'ro', isa => 'ArrayRef', required => 1 );
-has 'exec'              => ( is => 'ro', isa => 'Str',      default  => 'protein_alignment_from_nucleotides' );
-has 'translation_table' => ( is => 'rw', isa => 'Int',      default => 11 );
-has 'core_definition'   => ( is => 'ro', isa => 'Num',      default => 1 );
-has 'mafft'             => ( is => 'ro', isa => 'Bool',     default => 0 );
+has 'fasta_files'                 => ( is => 'ro', isa => 'ArrayRef', required => 1 );
+has 'exec'                        => ( is => 'ro', isa => 'Str',      default  => 'protein_alignment_from_nucleotides' );
+has 'translation_table'           => ( is => 'rw', isa => 'Int',      default => 11 );
+has 'core_definition'             => ( is => 'ro', isa => 'Num',      default => 1 );
+has 'mafft'                       => ( is => 'ro', isa => 'Bool',     default => 0 );
+has 'dont_delete_files'           => ( is => 'rw', isa => 'Bool',     default  => 0 );
+has 'num_input_files'             => ( is => 'ro', isa => 'Int',      required => 1);
 
 # Overload Role
 has '_memory_required_in_mb' => ( is => 'ro', isa => 'Int', lazy     => 1, builder => '_build__memory_required_in_mb' );
+has '_min_memory_in_mb'      => ( is => 'ro', isa => 'Int', default => 500 );
+has '_max_memory_in_mb'      => ( is => 'ro', isa => 'Int', default => 60000 );
 has '_queue'                 => ( is => 'rw', isa => 'Str', default  => 'normal' );
-has '_files_per_chunk'       => ( is => 'ro', isa => 'Int', default  => 25 );
+has '_files_per_chunk'       => ( is => 'ro', isa => 'Int', default  => 10 );
 has '_core_alignment_cmd'    => ( is => 'rw', isa => 'Str', lazy_build => 1 );
 
 
+
 sub _build__memory_required_in_mb {
     my ($self)          = @_;
-    my $memory_required = 5000;
+
+    my $largest_file_size = 1;
+    for my $file (@{$self->fasta_files})
+    {
+        my $file_size = -s $file;
+        if($file_size > $largest_file_size)
+        {
+            $largest_file_size = $file_size;
+        }
+    }
+    
+    my $approx_sequence_length_of_largest_file = $largest_file_size/ $self->num_input_files;
+    my $memory_required = int((($approx_sequence_length_of_largest_file*$approx_sequence_length_of_largest_file)/1000000) + $self->_min_memory_in_mb);
+    
+    $memory_required = $self->_max_memory_in_mb if($memory_required  > $self->_max_memory_in_mb);
+
     return $memory_required;
 }
 
 sub _command_to_run {
-    my ( $self, $fasta_files, ) = @_;
+    my ( $self, $fasta_files) = @_;
 	my $verbose = "";
 	if($self->verbose)
 	{
@@ -42,6 +62,7 @@ sub _build__core_alignment_cmd {
     
     my $core_cmd = "pan_genome_core_alignment";
     $core_cmd .= " -cd " . ($self->core_definition*100) if ( defined $self->core_definition );
+    $core_cmd .= " --dont_delete_files " if ( defined $self->dont_delete_files  && $self->dont_delete_files == 1 );
 
     return $core_cmd;
 }
@@ -97,7 +118,7 @@ Bio::Roary::External::GeneAlignmentFromNucleotides - Take in multi-FASTA files o
 
 =head1 VERSION
 
-version 3.3.2
+version 3.3.3
 
 =head1 SYNOPSIS
 
