@@ -1,5 +1,5 @@
 package Bio::Roary::SplitGroups;
-$Bio::Roary::SplitGroups::VERSION = '3.3.2';
+$Bio::Roary::SplitGroups::VERSION = '3.3.3';
 # ABSTRACT: 
 
 
@@ -9,7 +9,7 @@ use File::Path qw(make_path remove_tree);
 use File::Copy qw(move);
 use File::Temp;
 use File::Basename;
-use File::Slurp::Tiny 'read_lines';
+use File::Slurper 'read_lines';
 use Cwd;
 
 
@@ -81,7 +81,7 @@ sub _build__genes_to_neighbourhood
 	my ( $filename, $directories, $suffix ) = fileparse( $fasta_file, qr/\.[^.]*/ );
   	system('grep \> '.$fasta_file.'| sed  \'s/>//\' >'.$self->_gene_files_temp_dir_obj."/".$filename.$suffix ) ;
 	
-	my @genes = read_lines($self->_gene_files_temp_dir_obj."/".$filename.$suffix, chomp => 1 );
+	my @genes = read_lines($self->_gene_files_temp_dir_obj."/".$filename.$suffix );
 	
 	for(my $i =0; $i< @genes; $i++)
 	{
@@ -330,7 +330,7 @@ Bio::Roary::SplitGroups -
 
 =head1 VERSION
 
-version 3.3.2
+version 3.3.3
 
 =head1 SYNOPSIS
 
